@@ -282,3 +282,27 @@ class Contract(Base):
 
     def __str__(self):
         return f'Договор - {self.student}: {self.number} ({self.date_recieved})'
+
+
+class FamilyStatus(Base):
+    """
+    Семейное положение
+    """
+    __tablename__ = 'univer_family_status_1c'
+
+    # Идентификатор
+    id = Column('family_status_id', Integer, primary_key=True)
+
+    # Наименование
+    name_ru = Column('family_status_name_ru', String(500))
+    name_kz = Column('family_status_name_kz', String(500))
+    name_en = Column('family_status_name_en', String(500))
+
+    # Статус
+    status = Column(Integer)
+
+    def __repr__(self):
+        return '<FamilyStatus {} (id={} status={})>'.format(self, self.id, self.status)
+
+    def __str__(self):
+        return self.name_ru
