@@ -121,10 +121,8 @@ class LangDivision(Base):
 
 class DocumentIdentity(Base):
     """
-    Модель "Тип документа"
-    Статус: Выполнено
+    Тип документа
     """
-
     __tablename__ = 'univer_document_identity'
 
     id = Column('document_identity_type', Integer, primary_key=True)
